@@ -1,11 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelSQL, fields
+from trytond.modules.company.model import CompanyValueMixin
 from trytond.pool import PoolMeta
 from trytond.pyson import Eval
 
-from trytond.modules.company.model import CompanyValueMixin
-
 
 class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
@@ -27,14 +26,13 @@ class PartyPurchasePriceList(ModelSQL, CompanyValueMixin):
     __name__ = 'party.party.purchase_price_list'
 
     party = fields.Many2One(
-        'party.party', "Party", ondelete='CASCADE', select=True,
+        'party.party', "Party", ondelete='CASCADE',
         context={
             'company': Eval('company', -1),
             },
-        depends=['company'])
+        depends={'company'})
     purchase_price_list = fields.Many2One(
         'product.price_list', "Purchase Price List",
         domain=[
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
+            ])
